@@ -1,6 +1,5 @@
 # Embedding models
-from chesspos.models.cnn_autoencoder import CnnAutoencoder
+from chesspos.models.autoencoder import AutoencoderModel
 from chesspos.models.dense_autoencoder import DenseAutoencoder
-
-# Mixins
-from chesspos.models.chessposition_inspectable_autoencoder import ChesspositionInspectableAutoencoderMixin
\ No newline at end of file
+from chesspos.models.resnet_autoencoder import ResnetAutoencoder
+from chesspos.models.cnn_autoencoder import CnnAutoencoder
